""" Menu scene. """

import os

import pygame.locals as pgl

from .base import BaseScene
from ..constants import SCREEN_SIZE
from ..events import SceneChangeEvent
from ..widgets import TextButton
from ..loader import loader


class LoadLevelScene(BaseScene):

    def _list_stations(self):
        station_path = loader.full_path("stations")
        files = [f for f in os.listdir(station_path) if f.endswith(".json")]
        files.sort()
        return [loader.load_station(f) for f in files]

    def enter(self, gamestate):
        """Construct list of stations"""
        width = SCREEN_SIZE[0] / 2
        self._title = TextButton(
            'Select a planet:', (255, 255, 255), pos=(width, 75),
            size=32, font='bold', centre=True)
        height = 150
        self._buttons = []
        for station in self._list_stations():
            title = station["config"]["name"]
            pos = (width, height)
            button = TextButton(title, (255, 255, 255), pos=pos, centre=True)
            button.station = station
            height += button.get_height() + 20
            self._buttons.append(button)

    def render(self, surface, gamestate):
        surface.fill((0, 128, 128))
        self._title.render(surface)
        for button in self._buttons:
            button.render(surface)

    def _get_pressed(self, ev):
        for button in self._buttons:
            if button.pressed(ev):
                return button
        return None

    def _do_load(self, station, gamestate):
        from .day import DayScene
        print "Loading station", station["config"]["name"]
        gamestate.set_station(station)
        SceneChangeEvent.post(scene=DayScene())

    def event(self, ev, gamestate):
        if ev.type == pgl.KEYDOWN:
            if ev.key in (pgl.K_q, pgl.K_ESCAPE):
                from .menu import MenuScene
                SceneChangeEvent.post(scene=MenuScene())
        elif ev.type == pgl.MOUSEBUTTONDOWN:
            pressed = self._get_pressed(ev)
            if pressed:
                self._do_load(pressed.station, gamestate)
