""" Menu scene. """

import pygame.locals as pgl

from .base import BaseScene
from ..events import QuitEvent, SceneChangeEvent
from ..loader import loader
from ..constants import FONTS
from ..widgets import TextButton, SpacerButton
from ..utils import save_file_exists, get_save_data


class MenuScene(BaseScene):
    def enter(self, gamestate):
        if gamestate.station is None:
            print "Loading Station Alpha ..."
            gamestate.set_station(loader.load_station("station-alpha.json"))
        font_title = loader.load_font(FONTS['bold'], size=32)
        self._title = font_title.render('A Game with a title', True,
                                        (255, 255, 255))
        self._cont_but = TextButton("Continue / Retry", (255, 255, 255),
                                    name='continue')
        if not save_file_exists():
            self._cont_but.disable()
        self._menu = [
            TextButton("New Game", (255, 255, 255), name='new game'),
            self._cont_but,
            TextButton("Help", (255, 255, 255), name='help'),
            SpacerButton((50, 30)),
            TextButton("Quit", (255, 255, 255), name='quit'),
        ]

    def render(self, surface, gamestate):
        surface.fill((0, 128, 0))

        pos = ((surface.get_width() - self._title.get_width()) / 2, 50)
        surface.blit(self._title, pos, None)

        height = 150
        for item in self._menu:
            if not item.position:
                item.position = ((surface.get_width() - item.get_width()) / 2,
                                 height)
            item.render(surface)
            height += item.get_height() + 30

    def _get_pressed(self, ev):
        for button in self._menu:
            if button.pressed(ev):
                return button.name
        return None

    def _do_load_save(self, gamestate):
        gamestate.load_from_json(get_save_data())
        from .day import DayScene
        SceneChangeEvent.post(scene=DayScene())

    def _start_new_game(self):
        from .load_level import LoadLevelScene
        SceneChangeEvent.post(scene=LoadLevelScene())

    def _do_help(self):
        from .help import HelpScene
        SceneChangeEvent.post(scene=HelpScene())

    def event(self, ev, gamestate):
        if ev.type == pgl.KEYDOWN:
            if ev.key in (pgl.K_q, pgl.K_ESCAPE):
                QuitEvent.post()
            elif ev.key == pgl.K_n:
                from .night import NightScene
                SceneChangeEvent.post(scene=NightScene())
            elif ev.key == pgl.K_d:
                self._do_day()
            elif ev.key == pgl.K_l:
                self._start_new_game()
            elif ev.key == pgl.K_h:
                self._do_help()
        elif ev.type == pgl.MOUSEBUTTONDOWN:
            pressed = self._get_pressed(ev)
            if pressed == 'new game':
                self._start_new_game()
            elif pressed == 'continue':
                self._do_load_save(gamestate)
            elif pressed == 'help':
                self._do_help()
            elif pressed == 'quit':
                QuitEvent.post()
            elif pressed:
                print 'Pressed', pressed
